RAutocompleteRemoteCachePolicy class sealed
Cache policy for remote source results.
Constructors
- RAutocompleteRemoteCachePolicy.lastSuccessfulPerQuery({int maxEntries})
-
Cache the last successful result per unique query text.
constfactory
- RAutocompleteRemoteCachePolicy.none()
-
No caching - every request goes to the backend.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited