RAutocompleteFieldStyle class final
Styling sugar for the input field of RAutocomplete.
- Annotations
Constructors
- RAutocompleteFieldStyle({EdgeInsetsGeometry? containerPadding, Color? containerBackgroundColor, Color? containerBorderColor, double? containerBorderWidth, double? containerRadius, BorderRadius? containerBorderRadius, TextStyle? textStyle, Color? textColor, Color? placeholderColor, Color? labelColor, Size? minSize})
-
const
Properties
- containerBackgroundColor → Color?
-
final
- containerBorderColor → Color?
-
final
- containerBorderRadius → BorderRadius?
-
final
- containerBorderWidth → double?
-
final
- containerPadding → EdgeInsetsGeometry?
-
final
- containerRadius → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelColor → Color?
-
final
- minSize → Size?
-
final
- placeholderColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
final
- textStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toOverrides(
) → RTextFieldOverrides -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited