RAutocompleteStyle class final

Simple, Flutter-like styling sugar for RAutocomplete.

This type is NOT a new renderer contract. It is a convenience layer that is internally converted to RenderOverrides.only(...) for the field and options menu.

Priority (strong -> weak):

  1. explicit overrides
  2. style sugar
  3. theme/preset defaults
Annotations

Properties

field RAutocompleteFieldStyle?
Styling for the input field.
final
hashCode int
The hash code for this object.
no setterinherited
options RAutocompleteOptionsStyle?
Styling for the options menu.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited