RAutocompleteSelectedValuesCommands class final
Commands for rendering and interacting with selected values (multi-select).
- Annotations
Constructors
- RAutocompleteSelectedValuesCommands({required void removeById(ListboxItemId id), required void removeAt(int index)})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- removeAt → void Function(int index)
-
Removes a selected value by its index in
selectedItems.final - removeById → void Function(ListboxItemId id)
-
Removes a selected value by its stable item id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited