RAutocompleteSelectedValuesOverrides class final
Per-instance overrides for selected values rendering (contract level).
- Annotations
Constructors
- RAutocompleteSelectedValuesOverrides({RAutocompleteSelectedValuesPresentation? presentation})
-
const
- RAutocompleteSelectedValuesOverrides.tokens({RAutocompleteSelectedValuesPresentation? presentation})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- presentation → RAutocompleteSelectedValuesPresentation?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited