RAutocompleteSelectedValuesRenderRequest class final

Annotations

Constructors

RAutocompleteSelectedValuesRenderRequest({required BuildContext context, required List<HeadlessListItemModel> selectedItems, required RAutocompleteSelectedValuesCommands commands, RenderOverrides? overrides})
const

Properties

commands RAutocompleteSelectedValuesCommands
final
context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
overrides → RenderOverrides?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItems List<HeadlessListItemModel>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited