RDropdownAnchorContext class final
Context for the anchor (trigger button) slot.
- Annotations
Constructors
- RDropdownAnchorContext({required RDropdownButtonSpec spec, required RDropdownButtonState state, required HeadlessListItemModel? selectedItem, required RDropdownCommands commands})
-
const
Properties
- commands → RDropdownCommands
-
Commands for trigger interaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItem → HeadlessListItemModel?
-
Currently selected item (null if none).
final
- spec → RDropdownButtonSpec
-
Dropdown specification.
final
- state → RDropdownButtonState
-
Current state (focus, hover, pressed, disabled).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited