RDropdownButtonSpec class final

Dropdown specification (static, from widget props).

Annotations

Constructors

RDropdownButtonSpec({String? placeholder, String? semanticLabel, RDropdownVariant variant = RDropdownVariant.outlined, RDropdownSize size = RDropdownSize.medium})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
placeholder String?
Placeholder text when no value is selected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Accessibility label (for screen readers).
final
size RDropdownSize
Size variant.
final
variant RDropdownVariant
Visual variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited