highlightedIndex property
Index of currently highlighted item in the menu (null if none).
Highlighted != Selected. Highlight is keyboard navigation state.
Implementation
final int? highlightedIndex;
Index of currently highlighted item in the menu (null if none).
Highlighted != Selected. Highlight is keyboard navigation state.
final int? highlightedIndex;