selectIndex property
Select an item by index.
The component maps this index back to the generic value.
Implementation
final void Function(int index) selectIndex;
Select an item by index.
The component maps this index back to the generic value.
final void Function(int index) selectIndex;