RDropdownItemContentContext class final

Context for item content inside the menu item.

Annotations

Constructors

RDropdownItemContentContext({required HeadlessListItemModel item, required int index, required bool isHighlighted, required bool isSelected, required RDropdownCommands commands, required Widget child})
const

Properties

child Widget
Default content widget from the renderer.
final
commands RDropdownCommands
Commands.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Index in the items list.
final
isHighlighted bool
Whether this item is keyboard-highlighted.
final
isSelected bool
Whether this item is the selected value.
final
item → HeadlessListItemModel
The item data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited