RDropdownItemTokens class final

Resolved tokens for dropdown menu items.

Annotations

Constructors

RDropdownItemTokens({required TextStyle textStyle, required Color foregroundColor, required Color backgroundColor, required Color highlightBackgroundColor, required Color selectedBackgroundColor, required Color disabledForegroundColor, required EdgeInsetsGeometry padding, required double minHeight, required Color selectedMarkerColor})
const

Properties

backgroundColor Color
Normal background color.
final
disabledForegroundColor Color
Foreground color when item is disabled.
final
foregroundColor Color
Normal foreground color.
final
hashCode int
The hash code for this object.
no setteroverride
highlightBackgroundColor Color
Background color when item is keyboard-highlighted.
final
minHeight double
Minimum item height.
final
padding EdgeInsetsGeometry
Item content padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor Color
Background color when item is selected.
final
selectedMarkerColor Color
Color for selected item marker (checkmark).
final
textStyle TextStyle
Text style for item label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override