RDropdownMenuContext class final
Context for the menu slot.
- Annotations
Constructors
-
RDropdownMenuContext({required RDropdownButtonSpec spec, required RDropdownButtonState state, required List<
HeadlessListItemModel> items, required RDropdownCommands commands, required Widget itemBuilder(int index), HeadlessRequestFeatures features = HeadlessRequestFeatures.empty}) -
const
Properties
- commands → RDropdownCommands
-
Commands.
final
- features → HeadlessRequestFeatures
-
Request features (e.g., remote loading state).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(int index)
-
Builder for individual items (respects slot overrides).
final
-
items
→ List<
HeadlessListItemModel> -
List of items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spec → RDropdownButtonSpec
-
Dropdown specification.
final
- state → RDropdownButtonState
-
Current state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited