RDropdownMenuSurfaceContext class final

Context for the menu surface (background/container) slot.

Annotations

Constructors

RDropdownMenuSurfaceContext({required RDropdownButtonSpec spec, required RDropdownButtonState state, required Widget child, required RDropdownCommands commands, HeadlessRequestFeatures features = HeadlessRequestFeatures.empty})
const

Properties

child Widget
The menu content widget.
final
commands RDropdownCommands
Commands.
final
features → HeadlessRequestFeatures
Request features (e.g., remote loading state).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec RDropdownButtonSpec
Dropdown specification.
final
state RDropdownButtonState
Current state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited