RDropdownTriggerTokens class final

Resolved tokens for the dropdown trigger button.

Annotations

Constructors

RDropdownTriggerTokens({required TextStyle textStyle, required Color foregroundColor, required Color backgroundColor, required Color borderColor, required EdgeInsetsGeometry padding, required Size minSize, required BorderRadius borderRadius, required Color iconColor, required Color pressOverlayColor, required double pressOpacity})
const

Properties

backgroundColor Color
Background fill color.
final
borderColor Color
Border/outline color.
final
borderRadius BorderRadius
Corner radius.
final
foregroundColor Color
Foreground color (text, icon).
final
hashCode int
The hash code for this object.
no setteroverride
iconColor Color
Dropdown arrow icon color.
final
minSize Size
Minimum touch target size (WCAG/platform guidelines).
final
padding EdgeInsetsGeometry
Content padding.
final
pressOpacity double
Visual-only pressed opacity (e.g., Cupertino pressed fade).
final
pressOverlayColor Color
Visual-only press overlay color (e.g., Material pressed highlight).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
Text style for selected value / placeholder.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override