ROverlayPhase enum

Overlay lifecycle phases.

See docs/V1_DECISIONS.md → "0.2 Overlay" → "Close contract v1".

Inheritance
Available extensions

Values

opening → const ROverlayPhase

Overlay is entering (mount animation).

open → const ROverlayPhase

Overlay is fully visible.

closing → const ROverlayPhase

Overlay is exiting (exit animation).

closed → const ROverlayPhase

Overlay is removed from tree.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ROverlayPhase>
A constant List of the values in this enum, in order of their declaration.