RTextFieldOverrides class final

Per-instance overrides for TextField components (contract level).

This is a "token patch": all fields are nullable. Resolver takes base tokens and applies this patch on top.

Overrides affect only visual/layout, never behavior (focus/IME/selection).

See docs/FLEXIBLE_PRESETS_AND_PER_INSTANCE_OVERRIDES.md.

Annotations

Constructors

RTextFieldOverrides({EdgeInsetsGeometry? containerPadding, Color? containerBackgroundColor, Color? containerBorderColor, BorderRadius? containerBorderRadius, double? containerBorderWidth, double? containerElevation, Duration? containerAnimationDuration, TextStyle? labelStyle, Color? labelColor, TextStyle? helperStyle, Color? helperColor, TextStyle? errorStyle, Color? errorColor, double? messageSpacing, TextStyle? textStyle, Color? textColor, TextStyle? placeholderStyle, Color? placeholderColor, Color? cursorColor, Color? selectionColor, Color? iconColor, double? iconSpacing, Size? minSize})
const
RTextFieldOverrides.tokens({EdgeInsetsGeometry? containerPadding, Color? containerBackgroundColor, Color? containerBorderColor, BorderRadius? containerBorderRadius, double? containerBorderWidth, double? containerElevation, Duration? containerAnimationDuration, TextStyle? labelStyle, Color? labelColor, TextStyle? helperStyle, Color? helperColor, TextStyle? errorStyle, Color? errorColor, double? messageSpacing, TextStyle? textStyle, Color? textColor, TextStyle? placeholderStyle, Color? placeholderColor, Color? cursorColor, Color? selectionColor, Color? iconColor, double? iconSpacing, Size? minSize})
Named constructor for token overrides.
const

Properties

containerAnimationDuration Duration?
final
containerBackgroundColor Color?
final
containerBorderColor Color?
final
containerBorderRadius BorderRadius?
final
containerBorderWidth double?
final
containerElevation double?
final
containerPadding EdgeInsetsGeometry?
final
cursorColor Color?
final
errorColor Color?
final
errorStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
helperColor Color?
final
helperStyle TextStyle?
final
iconColor Color?
final
iconSpacing double?
final
labelColor Color?
final
labelStyle TextStyle?
final
messageSpacing double?
final
minSize Size?
final
placeholderColor Color?
final
placeholderStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionColor Color?
final
textColor Color?
final
textStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited