RTextFieldResolvedTokens class final
Resolved visual tokens for TextField rendering.
These are the final computed values that a renderer uses. Token resolution flow: spec + states → resolver → tokens → renderer.
All fields are required to ensure preset interoperability.
- Annotations
Constructors
- RTextFieldResolvedTokens({required EdgeInsetsGeometry containerPadding, required Color containerBackgroundColor, required Color containerBorderColor, required BorderRadius containerBorderRadius, required double containerBorderWidth, required double containerElevation, required Duration containerAnimationDuration, required TextStyle labelStyle, required Color labelColor, required TextStyle helperStyle, required Color helperColor, required TextStyle errorStyle, required Color errorColor, required double messageSpacing, required TextStyle textStyle, required Color textColor, required TextStyle placeholderStyle, required Color placeholderColor, required Color cursorColor, required Color selectionColor, required double disabledOpacity, required Color iconColor, required double iconSpacing, required Size minSize})
-
const
Properties
- containerAnimationDuration → Duration
-
final
- containerBackgroundColor → Color
-
final
- containerBorderColor → Color
-
final
- containerBorderRadius → BorderRadius
-
final
- containerBorderWidth → double
-
final
- containerElevation → double
-
final
- containerPadding → EdgeInsetsGeometry
-
final
- cursorColor → Color
-
final
- disabledOpacity → double
-
final
- errorColor → Color
-
final
- errorStyle → TextStyle
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- helperColor → Color
-
final
- helperStyle → TextStyle
-
final
- iconColor → Color
-
final
- iconSpacing → double
-
final
- labelColor → Color
-
final
- labelStyle → TextStyle
-
final
- messageSpacing → double
-
final
- minSize → Size
-
final
- placeholderColor → Color
-
final
- placeholderStyle → TextStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color
-
final
- textColor → Color
-
final
- textStyle → TextStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override