RTextFieldVariant enum

TextField visual variants.

This is a cross-preset intent that renderers interpret.

Inheritance
Available extensions

Values

filled → const RTextFieldVariant

Filled container style (default).

outlined → const RTextFieldVariant

Outlined container style.

underlined → const RTextFieldVariant

Underlined style.

This intent is commonly used in Material (bottom border only). Presets may map it to the nearest native equivalent.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RTextFieldVariant>
A constant List of the values in this enum, in order of their declaration.