SafeDropdownItemContext class final
- Annotations
Constructors
- SafeDropdownItemContext({required HeadlessListItemModel item, required int index, required bool isHighlighted, required bool isSelected, required Widget child})
-
const
Properties
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- isHighlighted → bool
-
final
- isSelected → bool
-
final
- item → HeadlessListItemModel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited