SafeDropdownMenuSurfaceContext class final
- Annotations
Constructors
- SafeDropdownMenuSurfaceContext({required RDropdownButtonSpec spec, required RDropdownButtonState state, required Widget child, required RDropdownCommands commands, RDropdownResolvedTokens? resolvedTokens})
-
const
Properties
- child → Widget
-
final
- commands → RDropdownCommands
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resolvedTokens → RDropdownResolvedTokens?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spec → RDropdownButtonSpec
-
final
- state → RDropdownButtonState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited