SafeDropdownRenderer class final

Safe scaffold for full dropdown renderer customization.

Provides close-contract safety and baseline item semantics.

Implemented types

Constructors

SafeDropdownRenderer({required SafeDropdownTriggerBuilder buildTrigger, required SafeDropdownMenuSurfaceBuilder buildMenuSurface, required SafeDropdownItemBuilder buildItem, SafeDropdownItemContentBuilder? buildItemContent, SafeDropdownEmptyStateBuilder? buildEmptyState, SafeDropdownChevronBuilder? buildChevron, RDropdownMenuMotionTokens? motion})
const

Properties

buildChevron SafeDropdownChevronBuilder?
final
buildEmptyState SafeDropdownEmptyStateBuilder?
final
buildItem SafeDropdownItemBuilder
final
buildItemContent SafeDropdownItemContentBuilder?
final
buildMenuSurface SafeDropdownMenuSurfaceBuilder
final
buildTrigger SafeDropdownTriggerBuilder
final
hashCode int
The hash code for this object.
no setterinherited
motion RDropdownMenuMotionTokens?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RDropdownRenderRequest request) Widget
Render a dropdown button with the given request.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited