SafeDropdownTriggerContext class final
- Annotations
Constructors
- SafeDropdownTriggerContext({required RDropdownButtonSpec spec, required RDropdownButtonState state, required HeadlessListItemModel? selectedItem, required String displayText, required RDropdownCommands commands, required Widget child, Widget? chevron, HeadlessPressableVisualEffectsController? visualEffects})
-
const
Properties
- chevron → Widget?
-
final
- child → Widget
-
final
- commands → RDropdownCommands
-
final
- displayText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItem → HeadlessListItemModel?
-
final
- spec → RDropdownButtonSpec
-
final
- state → RDropdownButtonState
-
final
- visualEffects → HeadlessPressableVisualEffectsController?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited