RAutocompleteOptionsStyle class final

Styling sugar for the options menu of RAutocomplete.

Annotations

Constructors

RAutocompleteOptionsStyle({Color? optionsBackgroundColor, Color? optionsBorderColor, double? optionsRadius, BorderRadius? optionsBorderRadius, double? optionsElevation, double? optionsMaxHeight, EdgeInsetsGeometry? optionsPadding, TextStyle? optionTextStyle, EdgeInsetsGeometry? optionPadding, double? optionMinHeight})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
optionMinHeight double?
final
optionPadding EdgeInsetsGeometry?
final
optionsBackgroundColor Color?
final
optionsBorderColor Color?
final
optionsBorderRadius BorderRadius?
final
optionsElevation double?
final
optionsMaxHeight double?
final
optionsPadding EdgeInsetsGeometry?
final
optionsRadius double?
final
optionTextStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOverrides() RDropdownOverrides
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited