removeAt property
Removes a selected value by its index in selectedItems.
Convenience for simple renderers that keep the request order.
Implementation
final void Function(int index) removeAt;
Removes a selected value by its index in selectedItems.
Convenience for simple renderers that keep the request order.
final void Function(int index) removeAt;