removeById property
void Function(ListboxItemId id)
removeById
final
Removes a selected value by its stable item id.
Recommended for renderers that may display selected items in any order.
Implementation
final void Function(ListboxItemId id) removeById;