RDropdownMenuTokens class final
Resolved tokens for the dropdown menu surface.
- Annotations
Constructors
- RDropdownMenuTokens({required Color backgroundColor, required double backgroundOpacity, required Color borderColor, required BorderRadius borderRadius, required double elevation, required double maxHeight, required EdgeInsetsGeometry padding, required double backdropBlurSigma, required Color shadowColor, required double shadowBlurRadius, required Offset shadowOffset, RDropdownMenuMotionTokens? motion})
-
const
Properties
- backdropBlurSigma → double
-
Backdrop blur sigma for translucent menu surfaces.
final
- backgroundColor → Color
-
Menu surface background color.
final
- backgroundOpacity → double
-
Background opacity for translucent menu surfaces.
final
- borderColor → Color
-
Menu border color.
final
- borderRadius → BorderRadius
-
Menu corner radius.
final
- elevation → double
-
Elevation/shadow depth.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxHeight → double
-
Maximum menu height before scrolling.
final
- motion → RDropdownMenuMotionTokens?
-
Motion tokens for enter/exit animations.
final
- padding → EdgeInsetsGeometry
-
Menu content padding (around item list).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowBlurRadius → double
-
Shadow blur radius for menu surface.
final
- shadowColor → Color
-
Shadow color for menu surface.
final
- shadowOffset → Offset
-
Shadow offset for menu surface.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override