RDropdownSemantics class final

Semantic information for dropdown accessibility.

This is passed in the render request so the renderer can provide appropriate semantic annotations if needed.

Annotations

Constructors

RDropdownSemantics({String? label, required bool isExpanded, required bool isEnabled, String? hint})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
hint String?
Optional hint for screen readers.
final
isEnabled bool
Whether the dropdown is currently enabled.
final
isExpanded bool
Whether the dropdown is currently expanded (menu open).
final
label String?
Accessibility label for screen readers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override