RTextFieldOverlayVisibilityMode enum
Visibility mode for overlay elements in text fields (prefix, suffix, clear button).
Controls when certain elements appear based on the text field's state.
Mirrors Flutter's OverlayVisibilityMode from CupertinoTextField.
Values
- never → const RTextFieldOverlayVisibilityMode
-
Never show the overlay element.
- whileEditing → const RTextFieldOverlayVisibilityMode
-
Show the overlay element only while the field is being edited (has focus).
- notEditing → const RTextFieldOverlayVisibilityMode
-
Show the overlay element only when the field is not being edited (no focus).
- always → const RTextFieldOverlayVisibilityMode
-
Always show the overlay element.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RTextFieldOverlayVisibilityMode> - A constant List of the values in this enum, in order of their declaration.